@@ -20,18 +20,18 @@ tv.compreg <- function(y, x, con = TRUE, B = 1, ncores = 1, xnew = NULL) {
   tvreg <- function(para, y, x, d) {
     be <- matrix(para, byrow = TRUE, ncol = d)
     mu1 <- cbind(1, exp(x%*%be) )
-    mu <- mu1/rowSums(mu1)
+    mu <- mu1 / rowSums(mu1)
     sum( abs(y - mu) )  ## Total variation
   }
 
   ## the next lines minimize the kl.compreg function and obtain the estimated betas
   runtime <- proc.time()
   ini <- as.vector( t( Compositional::kl.compreg(y, x[, -1, drop = FALSE], con = con)$be ) )
-  oop <- options( warn = -1 )
-  on.exit( options(oop) )
-  qa <- nlm(tvreg, ini, y = y, x = x, d = d)
-  qa <- nlm(tvreg, qa$estimate, y = y, x = x, d = d)
-  qa <- nlm(tvreg, qa$estimate, y = y, x = x, d = d)
+  suppressWarnings({
+    qa <- nlm(tvreg, ini, y = y, x = x, d = d)
+    qa <- nlm(tvreg, qa$estimate, y = y, x = x, d = d)
+    qa <- nlm(tvreg, qa$estimate, y = y, x = x, d = d)
+  })
   be <- matrix(qa$estimate, byrow = TRUE, ncol = d)
   covb <- NULL
   runtime <- proc.time() - runtime
@@ -56,8 +56,6 @@ tv.compreg <- function(y, x, con = TRUE, B = 1, ncores = 1, xnew = NULL) {
 
     } else {
       runtime <- proc.time()
-      oop <- options( warn = -1 )
-      on.exit( options(oop) )
       requireNamespace("doParallel", quietly = TRUE, warn.conflicts = FALSE)
       cl <- parallel::makePSOCKcluster(ncores)
       doParallel::registerDoParallel(cl)
@@ -67,9 +65,11 @@ tv.compreg <- function(y, x, con = TRUE, B = 1, ncores = 1, xnew = NULL) {
         yb <- y[ida, ]
         xb <- x[ida, ]
         ini <- as.vector( t( Compositional::kl.compreg(yb, xb[, -1, drop = FALSE], con = con)$be ) ) ## initial values
-        qa <- nlm(tvreg, ini, y = yb, x = xb, d = d)
-        qa <- nlm(tvreg, qa$estimate, y = yb, x = xb, d = d)
-        qa <- nlm(tvreg, qa$estimate, y = yb, x = xb, d = d)
+        suppressWarnings({
+          qa <- nlm(tvreg, ini, y = yb, x = xb, d = d)
+          qa <- nlm(tvreg, qa$estimate, y = yb, x = xb, d = d)
+          qa <- nlm(tvreg, qa$estimate, y = yb, x = xb, d = d)
+        })
         return( qa$estimate )
       }  ##  end foreach
       parallel::stopCluster(cl)
