@@ -39,24 +39,20 @@ zadr <- function(y, x, con = TRUE, B = 1, ncores = 2, xnew = NULL) {
   ##############
   ini.par <- c( log(ini.phi), as.vector(beta.ini) )  ## initial parameter values
   z <- list(ly1 = ly1, ly2 = ly2, x1 = x1, x2 = x2, a1 = a1, a2 = a2)
-  oop <- options( warn = -1 )
-  on.exit( options(oop) )
   suppressWarnings({
-    qa <- optim( ini.par, mixreg, z = z )
-    qa <- optim( qa$par, mixreg, z = z )
-    qa <- optim( qa$par, mixreg, z = z, hessian = TRUE, control = list(maxit = 1000) )
+    qa <- optim( ini.par, .mixreg, z = z )
+    qa <- optim( qa$par, .mixreg, z = z )
+    qa <- optim( qa$par, .mixreg, z = z, hessian = TRUE, control = list(maxit = 1000) )
   })
   phi <- exp( qa$par[1] )  ## final phi value
   be <- matrix( qa$par[-1], ncol = d ) ## final beta values
 
   if ( B > 1 ) {
     runtime <- proc.time()
-    oop <- options( warn = -1 )
-    on.exit( options(oop) )
     requireNamespace("doParallel", quietly = TRUE, warn.conflicts = FALSE)
     cl <- parallel::makePSOCKcluster(ncores)
     doParallel::registerDoParallel(cl)
-    betaboot <- foreach::foreach( i = 1:B, .combine = rbind, .export = c("Sample.int", "mixreg", "diri.nr"),
+    betaboot <- foreach::foreach( i = 1:B, .combine = rbind, .export = c("Sample.int", ".mixreg", "diri.nr"),
                                  .packages = c("Rfast2", "Compositional") ) %dopar% {
       ida <- Rfast2::Sample.int(n, n, replace = TRUE)
       yb <- y[ida, ]
@@ -89,12 +85,11 @@ zadr <- function(y, x, con = TRUE, B = 1, ncores = 2, xnew = NULL) {
       ini.phi <- Compositional::zad.est(yb)$phi
       ini.par <- c( log(ini.phi), as.vector(beta.ini) )  ## initial parameter values
       z <- list(ly1 = ly1, ly2 = ly2, x1 = x1, x2 = x2, a1 = a1, a2 = a2)
-      oop <- options( warn = -1 )
-      on.exit( options(oop) )
-      qa <- optim( ini.par, mixreg, z = z )
-      qa <- optim( qa$par, mixreg, z = z )
-      qa <- optim( qa$par, mixreg, z = z, control = list(maxit = 1000) )
-
+      suppressWarnings({
+        qa <- optim( ini.par, .mixreg, z = z )
+        qa <- optim( qa$par, .mixreg, z = z )
+        qa <- optim( qa$par, .mixreg, z = z, control = list(maxit = 1000) )
+      })
       return( qa$par )
     }  ##  end foreach
     parallel::stopCluster(cl)
@@ -137,5 +132,38 @@ zadr <- function(y, x, con = TRUE, B = 1, ncores = 2, xnew = NULL) {
 
 
 
+.mixreg <- function(param, z) {
+  ## separation of phi and the betas
+  ## and the exponential to avoid negative values of phi
+  phi <- exp( param[1] )   ;   para <- param[-1]
+  ly1 <- z$ly1     ;     ly2 <- z$ly2
+  x1 <- z$x1     ;     x2 <- z$x2
+  a1 <- z$a1     ;     a2 <- z$a2
+  dm <- dim(ly1)
+  D <- dm[2]    ;    d <- D - 1
+  n1 <- length(a1)    ;   n2 <- length(a2)
+  ## n1 is the sample size of the compositional vectors with no zeros
+  ## n2 is the sample size of the compositional vectors with zeros
+  n <- n1 + n2  ## total sample size
+  ## next we separate the compositional vectors, those which contain
+  ## zeros and those without. The same separation is performed for the
+  ## independent variable(s)
+  be <- matrix(para, ncol = d)   ## be is the matrix of the betas
+  be <- cbind(0, be)
+  mu1 <- exp(x1 %*% be)
+  mu <- mu1 / Rfast::rowsums(mu1) ## fitted values
+  ## next we find the fitted values for the compositional vectors with zeros
+  ly3 <- ly2
+  ind <- which(is.infinite(ly2))
+  ly3[ind] <- 0
+  mu2 <- exp(x2 %*% be )
+  mu2[ind] <- 0
+  mu2 <- mu2 / Rfast::rowsums(mu2)
+  zeros <- - sum( lgamma(phi * mu2[mu2>0]), na.rm = TRUE ) + sum( (mu2 * phi - 1) * ly3, na.rm = TRUE )
+  ba <- phi * mu
+  f <-  - n * lgamma(phi) + sum( lgamma( ba[ba>0] ), na.rm = TRUE ) - sum( (ba - 1) * ly1, na.rm = TRUE ) - zeros
+  f
+}
+
 
 
